@@ -29,9 +29,12 @@ OC.L10N.register(
     "Go back" : "Mine tagasi",
     "Email address" : "E-posti aadress",
     "Cancel" : "Loobu",
+    "Accounts" : "Kasutajakontod",
     "General" : "Üldine",
+    "Layout" : "Välimus",
     "List" : "Nimekiri",
     "Register" : "Registreeru",
+    "About" : "Rakendusest",
     "Keyboard shortcuts" : "Klaviatuuri otseteed",
     "Archive" : "Arhiiv",
     "Delete" : "Kustuta",
@@ -80,10 +83,12 @@ OC.L10N.register(
     "Message" : "Sõnum",
     "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
     "Add" : "Lisa",
+    "Show less" : "Näita vähem",
     "Clear" : "Tühjenda",
     "Close" : "Sulge",
     "Date" : "Kuupäev",
     "Tags" : "Sildid",
+    "Last 7 days" : "Viimase 7 päeva jooksul",
     "Custom" : "Kohandatud",
     "Tag already exists" : "Silt on juba olemas",
     "Copy translated text" : "Kopeeri tõlgitud tekst",
@@ -110,6 +115,7 @@ OC.L10N.register(
     "Trash" : "Prügikast",
     "{from}\n{subject}" : "{from}\n{subject}",
     "Discard changes" : "Hülga muudatused",
+    "Message sent" : "Sõnum on saadetud",
     "Error loading message" : "Tõrge kirja laadimisel",
     "Forwarding to %s" : "Edasta %s",
     "Redirect" : "Suunamine"
