@@ -21,6 +21,25 @@ OC.L10N.register(
     "Sent messages are saved in:" : "Испратените пораки се зачувани во:",
     "Deleted messages are moved in:" : "Избришаните пораки се преместени во:",
     "Archived messages are moved in:" : "Архивираните пораки се преместени во:",
+    "Connecting" : "Поврзување",
+    "Reconnect Google account" : "Повторно поврзи се Google сметка",
+    "Sign in with Google" : "Најави се со Google",
+    "Save" : "Зачувај",
+    "Connect" : "Поврзи се",
+    "Looking up configuration" : "Побарување конфигурација",
+    "Checking mail host connectivity" : "Проверка на врската со е-пошта серверот",
+    "Configuration discovery failed. Please use the manual settings" : "Неуспешна детекција на конфигурација. Користете рачни поставки",
+    "Password required" : "Потребна е лозинка",
+    "Testing authentication" : "Тестирање на автентикација",
+    "Loading account" : "Вчирување на сметка",
+    "Account updated" : "Сметката е ажурирана",
+    "IMAP server is not reachable" : "IMAP серверот не е достапен",
+    "SMTP server is not reachable" : "SMTP серверот не е достапен",
+    "IMAP username or password is wrong" : "IMAP лозинката или корисничкото име се грешни",
+    "SMTP username or password is wrong" : "SMTP лозинката или корисничкото име се грешни",
+    "IMAP connection failed" : "Неуспешна IMAP врска",
+    "SMTP connection failed" : "Неуспешна SMTP врска",
+    "There was an error while setting up your account" : "Настана грешка при поставување на вашата сметка",
     "Auto" : "Автоматски",
     "Name" : "Име",
     "Mail address" : "Адреса на е-пошта",
@@ -44,25 +63,6 @@ OC.L10N.register(
     "SMTP User" : "SMTP корисник",
     "SMTP Password" : "SMTP лозинка",
     "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "За да работи Google сметка, потребно е да активирате дво-факторна авторизација за Google и да генерирате лозинка за апликација.",
-    "Connecting" : "Поврзување",
-    "Reconnect Google account" : "Повторно поврзи се Google сметка",
-    "Sign in with Google" : "Најави се со Google",
-    "Save" : "Зачувај",
-    "Connect" : "Поврзи се",
-    "Looking up configuration" : "Побарување конфигурација",
-    "Checking mail host connectivity" : "Проверка на врската со е-пошта серверот",
-    "Configuration discovery failed. Please use the manual settings" : "Неуспешна детекција на конфигурација. Користете рачни поставки",
-    "Password required" : "Потребна е лозинка",
-    "Testing authentication" : "Тестирање на автентикација",
-    "Loading account" : "Вчирување на сметка",
-    "Account updated" : "Сметката е ажурирана",
-    "IMAP server is not reachable" : "IMAP серверот не е достапен",
-    "SMTP server is not reachable" : "SMTP серверот не е достапен",
-    "IMAP username or password is wrong" : "IMAP лозинката или корисничкото име се грешни",
-    "SMTP username or password is wrong" : "SMTP лозинката или корисничкото име се грешни",
-    "IMAP connection failed" : "Неуспешна IMAP врска",
-    "SMTP connection failed" : "Неуспешна SMTP врска",
-    "There was an error while setting up your account" : "Настана грешка при поставување на вашата сметка",
     "Account settings" : "Праметри за сметката",
     "Signature" : "Потпис",
     "A signature is added to the text of new messages and replies." : "Потписот ќе се додава на крајот од текстот на нови пораки и одговори.",
@@ -82,6 +82,7 @@ OC.L10N.register(
     "Add alias" : "Додади псевдоним",
     "Create alias" : "Креирај алијас",
     "Cancel" : "Откажи",
+    "Could not update preference" : "Неможе да се ажурираат параметрите",
     "Mail settings" : "Параметри за е-пошта",
     "Accounts" : "Сметки",
     "Add mail account" : "Додади е-пошта сметка",
@@ -91,6 +92,7 @@ OC.L10N.register(
     "Register" : "Регистрирај се",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Дозволете апликацијата да собира податоци за вашите интеракции. Врз основа на овие податоци, апликацијата ќе се прилагоди на вашите потреби. Податоците ќе се зачувуваат само локално.",
     "Trusted senders" : "Доверливи испраќачи",
+    "About" : "За",
     "Keyboard shortcuts" : "Кратенки преку тастатура",
     "Compose new message" : "Состави нова порака",
     "Newer message" : "Понови пораки",
@@ -102,13 +104,22 @@ OC.L10N.register(
     "Search" : "Барај",
     "Send" : "Прати",
     "Refresh" : "Освежи",
-    "Could not update preference" : "Неможе да се ажурираат параметрите",
-    "Select an alias" : "Избери алијас",
-    "Update Certificate" : "Ажурирај сертификат",
     "No certificate" : "Нема сертификат",
     "Certificate updated" : "Сертификатот е ажуриран",
     "Could not update certificate" : "Неможе да се ажурира сертификатот",
     "{commonName} - Valid until {expiryDate}" : "{commonName} - Валиден до {expiryDate}",
+    "Select an alias" : "Избери алијас",
+    "Update Certificate" : "Ажурирај сертификат",
+    "Encrypt with S/MIME and send later" : "Шифрирај со S/MIME и испрати ја подоцна",
+    "Encrypt with S/MIME and send" : "Шифрирај со S/MIME и испрати",
+    "Encrypt with Mailvelope and send later" : "Шифрирај со Mailvelope и испрати ја подоцна",
+    "Encrypt with Mailvelope and send" : "Шифрирај со Mailvelope и испрати",
+    "Send later" : "Испрати покасно",
+    "Message {id} could not be found" : "Пораката {id} не е пронајдена",
+    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Сите постоечки форматирања (како пример: болд, потцртан текст, италик итн.) ќе бидат отстранети.",
+    "Turn off formatting" : "Исклучи форматирање",
+    "Turn off and remove formatting" : "Исклучи и острани форматирање",
+    "Keep formatting" : "Зачувај го форматирањето",
     "From" : "Од",
     "Select account" : "Избете сметка",
     "To" : "До",
@@ -131,7 +142,6 @@ OC.L10N.register(
     "Disable formatting" : "Оневозможи форматирање",
     "Upload attachment" : "Прикачи прилог",
     "Add attachment from Files" : "Додади прилог од датотеките",
-    "Send later" : "Испрати покасно",
     "Request a read receipt" : "Побарај потврда за прочитана порака",
     "Sign message with S/MIME" : "Потпиши ја пораката со S/MIME",
     "Encrypt message with S/MIME" : "Шифрирај порака со S/MIME",
@@ -142,18 +152,9 @@ OC.L10N.register(
     "Monday morning" : "Понеделник наутро",
     "Custom date and time" : "Одреден датум и време",
     "Enter a date" : "Внеси датум",
-    "Encrypt with S/MIME and send later" : "Шифрирај со S/MIME и испрати ја подоцна",
-    "Encrypt with S/MIME and send" : "Шифрирај со S/MIME и испрати",
-    "Encrypt with Mailvelope and send later" : "Шифрирај со Mailvelope и испрати ја подоцна",
-    "Encrypt with Mailvelope and send" : "Шифрирај со Mailvelope и испрати",
-    "Message {id} could not be found" : "Пораката {id} не е пронајдена",
-    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Сите постоечки форматирања (како пример: болд, потцртан текст, италик итн.) ќе бидат отстранети.",
-    "Turn off formatting" : "Исклучи форматирање",
-    "Turn off and remove formatting" : "Исклучи и острани форматирање",
-    "Keep formatting" : "Зачувај го форматирањето",
+    "Choose" : "Избери",
     "Choose a file to add as attachment" : "Избери датотека за да додадете прилог",
     "Choose a file to share as a link" : "Избери датотека за да се сподели како линк",
-    "Choose" : "Избери",
     "_{count} attachment_::_{count} attachments_" : ["{count} прилог","{count} прилози"],
     "Untitled message" : "Неименувана порака",
     "Confirm" : "Потврди",
@@ -161,6 +162,16 @@ OC.L10N.register(
     "Rich text" : "Богат текст",
     "No messages in this mailbox" : "Нема пораки во ова сандаче",
     "No messages" : "Нема пораки",
+    "Blind copy recipients only" : "Само приматели на слепи копии",
+    "No subject" : "Нема наслов",
+    "Later today – {timeLocale}" : "Денес покасно – {timeLocale}",
+    "Set reminder for later today" : "Постави потсетник за денес покасно",
+    "Tomorrow – {timeLocale}" : "Утре – {timeLocale}",
+    "Set reminder for tomorrow" : "Постави потсетник за утре",
+    "Set reminder for this weekend" : "Постави потсетник за овој викенд",
+    "Set reminder for next week" : "Постави потсетник за наредната недела",
+    "No trash mailbox configured" : "Нема конфигурирано сандаче за отпадоци",
+    "Could not delete message" : "Неможе да се избрише пораката",
     "Draft: " : "Шаблон:",
     "This message is unread" : "Оваа порака не е прочитана",
     "Favorite" : "Омилени",
@@ -176,14 +187,6 @@ OC.L10N.register(
     "Create event" : "Креирај настан",
     "Create task" : "Креирај задача",
     "Download message" : "Преземи порака",
-    "Blind copy recipients only" : "Само приматели на слепи копии",
-    "No subject" : "Нема наслов",
-    "Set reminder for later today" : "Постави потсетник за денес покасно",
-    "Set reminder for tomorrow" : "Постави потсетник за утре",
-    "Set reminder for this weekend" : "Постави потсетник за овој викенд",
-    "Set reminder for next week" : "Постави потсетник за наредната недела",
-    "No trash mailbox configured" : "Нема конфигурирано сандаче за отпадоци",
-    "Could not delete message" : "Неможе да се избрише пораката",
     "Load more" : "Вчитај повеќе",
     "_Mark {number} read_::_Mark {number} read_" : ["Означи {number} прочитана","Означи {number} прочитани"],
     "_Mark {number} unread_::_Mark {number} unread_" : ["Означи {number} непрочитана","Означи {number} непрочитани"],
@@ -192,11 +195,13 @@ OC.L10N.register(
     "_Unselect {number}_::_Unselect {number}_" : ["Од-означи {number}","Од-означи {number}"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Препрати како прилог","Препрати {number} како прилозиt"],
     "Report this bug" : "Пријави грешка",
+    "Event created" : "Создаден е настан",
+    "Could not create event" : "Неможе да се креира настан",
     "All day" : "Цели денови",
     "Select calendar" : "Избери календар",
     "Create" : "Креирај",
-    "Event created" : "Создаден е настан",
-    "Could not create event" : "Неможе да се креира настан",
+    "This event was updated" : "Овој настан беше ажуриран",
+    "{attendeeName} accepted your invitation" : "{attendeeName} ја прифати вашата покана",
     "You have been invited to an event" : "Поканети сте на настан",
     "This event was cancelled" : "Овој настан беше откажан",
     "Save to" : "Зачувај во",
@@ -206,21 +211,19 @@ OC.L10N.register(
     "Decline" : "Одбиј",
     "More options" : "Повеќе опции ",
     "This event is in the past." : "Овој настан е во минатото.",
-    "This event was updated" : "Овој настан беше ажуриран",
-    "{attendeeName} accepted your invitation" : "{attendeeName} ја прифати вашата покана",
+    "individual" : "индивидуално",
     "domain" : "домен",
     "Remove" : "Отстрани ",
     "email" : "е-пошта",
-    "individual" : "индивидуално",
     "Itinerary for {type} is not supported yet" : "Итинерар за {type} сеуште не е поддржан",
     "Could not open mailbox" : "Неможе да се отвори сандачето",
     "Loading messages …" : "Вчитување пораки ...",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Индексирање на пораките. Ова може да трае многу долго за големи сандачиња.",
     "Choose target mailbox" : "Изберете дојдовно сандаче",
     "No more submailboxes in here" : "Нема повеќе подсандачиња тука",
+    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Пораките автоматски ќе бидат означени како важни врз основа на кои пораки сте комуницирале или сте ги означиле како важни. На почетокот можеби ќе треба рачно да ја менувате важноста да го научите системот, но тоа ќе се подобрува со текот на времето.",
     "Important info" : "Важна информација",
     "Other" : "Останато",
-    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Пораките автоматски ќе бидат означени како важни врз основа на кои пораки сте комуницирале или сте ги означиле како важни. На почетокот можеби ќе треба рачно да ја менувате важноста да го научите системот, но тоа ќе се подобрува со текот на времето.",
     "The sender of this message has asked to be notified when you read this message." : "Испраќачот на оваа порака посака да биде известен кога ќе ја прочитате оваа порака.",
     "Notify the sender" : "Извести го испраќачот",
     "You sent a read confirmation to the sender of this message." : "Испративте потврда до испраќачот дека е прочитана пораката.",
@@ -231,12 +234,12 @@ OC.L10N.register(
     "View source" : "Погледни извор",
     "Download thread data for debugging" : "Преземи информации за развивачи",
     "Message body" : "Тело на пораката",
+    "Unnamed" : "Неименувана",
+    "Embedded message" : "Вградена порака",
     "Choose a folder to store the attachment in" : "Избери папка за зачувување на прилогот",
     "Import into calendar" : "Увези во календар",
     "Download attachment" : "Преземи прилог",
     "Save to Files" : "Зачувај во датотеките",
-    "Unnamed" : "Неименувана",
-    "Embedded message" : "Вградена порака",
     "Choose a folder to store the attachments in" : "Избери папка за зачувување на прилозите",
     "Save all to Files" : "Зачувај ги сите во датотеките",
     "Download Zip" : "Преземи Zip",
@@ -251,21 +254,29 @@ OC.L10N.register(
     "Move" : "Премести",
     "Moving" : "Преместува",
     "Moving message" : "Преместување порака",
+    "Loading …" : "Се вчитува…",
+    "Not supported by the server" : "Не е поддржано од серверот",
+    "{usage} of {limit} used" : "Искористено {usage} од {limit}",
+    "Remove account" : "Отстрани сметка",
+    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Сметката за {email} и зачуваните податоци ќе бидат избришани, но нема да бидат избришани од провајдерот на електронската пошта.",
+    "Remove {email}" : "Одстрани {email}",
     "Quota" : "Квота",
     "Show only subscribed mailboxes" : "Прикажи само претплатени сандачиња",
     "Add mailbox" : "Додади сандаче",
     "Saving" : "Зачувува",
     "Move up" : "Помести горе",
     "Move down" : "Помести доле",
-    "Remove account" : "Отстрани сметка",
-    "Loading …" : "Се вчитува…",
-    "Not supported by the server" : "Не е поддржано од серверот",
-    "{usage} of {limit} used" : "Искористено {usage} од {limit}",
-    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Сметката за {email} и зачуваните податоци ќе бидат избришани, но нема да бидат избришани од провајдерот на електронската пошта.",
-    "Remove {email}" : "Одстрани {email}",
     "Show all subscribed mailboxes" : "Прикажи ги сите сандачиња со претплата",
     "Show all mailboxes" : "Прикажи ги сите сандачиња",
     "Collapse mailboxes" : "Сокриј сандачиња",
+    "_{total} message_::_{total} messages_" : ["{total} порака","{total} пораки"],
+    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} непрочитана од {total}","{unread} непрочитани од {total}"],
+    "Clear mailbox {name}" : "Исчисти сандаче {name}",
+    "Clear mailbox" : "Исчисти сандаче",
+    "The mailbox and all messages in it will be deleted." : "Сандачето и сеите пораки во него ќе бидат избришани.",
+    "Delete mailbox" : "Избриши сандаче",
+    "Delete mailbox {name}" : "Избриши сандаче {name}",
+    "An error occurred, unable to rename the mailbox." : "Настана грешка, неможе да се промени името на сандачето.",
     "Mark all as read" : "Означи ги сите како прочитани",
     "Mark all messages of this mailbox as read" : "Означи ги како прочитани сите пораки од ова сандаче ",
     "Add submailbox" : "Додади подсандаче",
@@ -275,20 +286,8 @@ OC.L10N.register(
     "Clear locally cached data, in case there are issues with synchronization." : "Исчистете ги локално зачуваните податоци, во случај да има проблеми со синхронизацијата.",
     "Subscribed" : "Претплатени",
     "Sync in background" : "Синхронизација во позадина",
-    "Clear mailbox" : "Исчисти сандаче",
-    "Delete mailbox" : "Избриши сандаче",
-    "Clear mailbox {name}" : "Исчисти сандаче {name}",
-    "The mailbox and all messages in it will be deleted." : "Сандачето и сеите пораки во него ќе бидат избришани.",
-    "Delete mailbox {name}" : "Избриши сандаче {name}",
-    "An error occurred, unable to rename the mailbox." : "Настана грешка, неможе да се промени името на сандачето.",
-    "_{total} message_::_{total} messages_" : ["{total} порака","{total} пораки"],
     "Outbox" : "Излезно сандаче",
     "New message" : "Нова порака",
-    "Error sending your message" : "Грешка при испраќање на пораката",
-    "Retry" : "Обидете се повторно",
-    "Uploading attachments …" : "Прикачување на прилог ...",
-    "Sending …" : "Испраќам ...",
-    "Send anyway" : "Испрати секако",
     "Edit message" : "Уреди порака",
     "Draft" : "Шаблон",
     "Reply" : "Одговор",
@@ -296,6 +295,11 @@ OC.L10N.register(
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Се обидувате да испратите до многу примачи во До и/или Cc. Можете да користите Bcc за да ги скриете адресите на примачите.",
     "Message discarded" : "Пораката е отфрлена",
     "Could not discard message" : "Неможе да се отфрли порака",
+    "Error sending your message" : "Грешка при испраќање на пораката",
+    "Retry" : "Обидете се повторно",
+    "Uploading attachments …" : "Прикачување на прилог ...",
+    "Sending …" : "Испраќам ...",
+    "Send anyway" : "Испрати секако",
     "Autoresponder off" : "Исклучен автоматски одговор",
     "Autoresponder on" : "Вклучен автоматски одговор",
     "First day" : "Прв ден",
@@ -314,6 +318,7 @@ OC.L10N.register(
     "Add" : "Додади",
     "Show less" : "Помалку",
     "Show more" : "Прикажи повеќе",
+    "Clear" : "Исчисти",
     "Search in mailbox" : "Барај во сандачето",
     "Close" : "Затвори",
     "Search parameters" : "Параметри за пребарување",
@@ -329,7 +334,6 @@ OC.L10N.register(
     "Marked as" : "Означено како",
     "Has attachments" : "Има прилози",
     "Last 7 days" : "Предходни 7 дена",
-    "Clear" : "Исчисти",
     "Sieve Port" : "Sieve порта",
     "Custom" : "Прилагодено",
     "Sieve User" : "Sieve корисник",
@@ -339,16 +343,16 @@ OC.L10N.register(
     "Signature …" : "Потпис ...",
     "Save signature" : "Зачувај потпис",
     "Place signature above quoted text" : "Постави го потписот над цитираниот текст",
-    "Saving new tag name …" : "Зачувување на ново име на ознака ...",
     "An error occurred, unable to rename the tag." : "Настана грешка, неможе да се преименува ознака.",
-    "Add default tags" : "Додади стандардни ознаки",
-    "Add tag" : "Додади ознака",
-    "Saving tag …" : "Зачувување ознака …",
+    "Saving new tag name …" : "Зачувување на ново име на ознака ...",
     "Tag name is a hidden system tag" : "Името на ознаката е сокриена системска ознака",
     "Tag already exists" : "Тагот веќе постои",
     "An error occurred, unable to create the tag." : "Настана грешка, неможе да се креира ознака.",
-    "Not found" : "Не е пронајдено",
+    "Add default tags" : "Додади стандардни ознаки",
+    "Add tag" : "Додади ознака",
+    "Saving tag …" : "Зачувување ознака …",
     "Could not load your message thread" : "Неможат да се преземат информации за пораката",
+    "Not found" : "Не е пронајдено",
     "Reply all" : "Одговори на сите",
     "Reply to sender only" : "Одговор само до испраќачот",
     "Mark as unfavorite" : "Од-означи омилена",
@@ -357,16 +361,16 @@ OC.L10N.register(
     "Mark as read" : "Означи како прочитано",
     "Delete message" : "Избриши порака",
     "Message source" : "Извор на пораката",
-    "(organizer)" : "(organizer)",
     "Untitled event" : "Неименуван настан",
+    "(organizer)" : "(organizer)",
     "Import into {calendar}" : "Увези во {calendar}",
     "Event imported into {calendar}" : "Настанот е увезен во {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Лет {flightNr} од {depAirport} до {arrAirport}",
     "Airplane" : "Авион",
     "Reservation {id}" : "Резервација {id}",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Лет {flightNr} од {depAirport} до {arrAirport}",
-    "Train" : "Воз",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} од {depStation} до {arrStation}",
     "Train from {depStation} to {arrStation}" : "Воз од  {depStation} до {arrStation}",
+    "Train" : "Воз",
     "Flag" : "Знаме",
     "Actions" : "Акции",
     "New action" : "Нова акција",
@@ -399,8 +403,6 @@ OC.L10N.register(
     "Account connected" : "Сметката е поврзана",
     "You can close this window" : "Можете да го затворите овој прозорец",
     "Connect your mail account" : "Поврзете ја вашата е-пошта сметка",
-    "Tomorrow – {timeLocale}" : "Утре – {timeLocale}",
-    "Later today – {timeLocale}" : "Денес покасно – {timeLocale}",
     "All" : "Сите",
     "Drafts" : "Шаблони",
     "Favorites" : "Омилени",
@@ -431,7 +433,6 @@ OC.L10N.register(
     "Redirect" : "Пренасочи",
     "The link leads to %s" : "Линкот води кон %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Доколку несакате да ја посетите страната, можете да се вратите кон <a href=\"%s\">Е-пошта</a>.",
-    "Continue to %s" : "Продолжи до %s",
-    "Unselect" : "Поништи избор"
+    "Continue to %s" : "Продолжи до %s"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
