@@ -23,6 +23,7 @@ use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Db\QBMapper;
 use OCP\AppFramework\Db\TTransactional;
 use OCP\AppFramework\Utility\ITimeFactory;
+use OCP\DB\Exception;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\IDBConnection;
 use OCP\IUser;
@@ -39,6 +40,7 @@ use function ltrim;
 use function mb_convert_encoding;
 use function mb_strcut;
 use function OCA\Mail\array_flat_map;
+use function strlen;
 
 /**
  * @template-extends QBMapper<Message>
@@ -235,7 +237,7 @@ class MessageMapper extends QBMapper {
 			foreach ($messages as $message) {
 				$query->setParameter(
 					'thread_root_id',
-					$message->getThreadRootId(),
+					self::filterMessageIdLength($message->getThreadRootId()),
 					$message->getThreadRootId() === null ? IQueryBuilder::PARAM_NULL : IQueryBuilder::PARAM_STR
 				);
 				$query->setParameter('id', $message->getDatabaseId(), IQueryBuilder::PARAM_INT);
@@ -255,6 +257,7 @@ class MessageMapper extends QBMapper {
 	/**
 	 * @param Message ...$messages
 	 * @return void
+	 * @throws Exception
 	 */
 	public function insertBulk(Account $account, Message ...$messages): void {
 		$this->db->beginTransaction();
@@ -290,11 +293,11 @@ class MessageMapper extends QBMapper {
 			foreach ($messages as $message) {
 				$qb1->setParameter('uid', $message->getUid(), IQueryBuilder::PARAM_INT);
 				$qb1->setParameter('message_id', $message->getMessageId(), IQueryBuilder::PARAM_STR);
-				$inReplyTo = $message->getInReplyTo();
+				$inReplyTo = self::filterMessageIdLength($message->getInReplyTo());
 				$qb1->setParameter('in_reply_to', $inReplyTo, $inReplyTo === null ? IQueryBuilder::PARAM_NULL : IQueryBuilder::PARAM_STR);
 				$references = $message->getReferences();
 				$qb1->setParameter('references', $references, $references === null ? IQueryBuilder::PARAM_NULL : IQueryBuilder::PARAM_STR);
-				$threadRootId = $message->getThreadRootId();
+				$threadRootId = self::filterMessageIdLength($message->getThreadRootId());
 				$qb1->setParameter('thread_root_id', $threadRootId, $threadRootId === null ? IQueryBuilder::PARAM_NULL : IQueryBuilder::PARAM_STR);
 				$qb1->setParameter('mailbox_id', $message->getMailboxId(), IQueryBuilder::PARAM_INT);
 				$qb1->setParameter('subject', $message->getSubject(), IQueryBuilder::PARAM_STR);
@@ -347,6 +350,20 @@ class MessageMapper extends QBMapper {
 		}
 	}
 
+	/**
+	 * @throws Exception
+	 */
+	private static function filterMessageIdLength(?string $messageId): ?string {
+		if ($messageId === null) {
+			return null;
+		}
+		if (strlen($messageId) > 1023) {
+			throw new Exception("IMAP message ID $messageId is too long for the database");
+		}
+
+		return $messageId;
+	}
+
 	/**
 	 * @param Account $account
 	 * @param bool $permflagsEnabled
@@ -378,8 +395,8 @@ class MessageMapper extends QBMapper {
 
 		$updateData = [];
 		foreach ($flags as $flag) {
-			$updateData[$flag.'_true'] = [];
-			$updateData[$flag.'_false'] = [];
+			$updateData[$flag . '_true'] = [];
+			$updateData[$flag . '_false'] = [];
 		}
 
 		foreach ($messages as $message) {
@@ -460,7 +477,7 @@ class MessageMapper extends QBMapper {
 						$queryTrue->expr()->eq('mailbox_id', $queryTrue->createNamedParameter($mailboxId, IQueryBuilder::PARAM_INT)),
 						$queryTrue->expr()->eq($flag, $queryTrue->createNamedParameter(0, IQueryBuilder::PARAM_INT))
 					));
-				foreach (array_chunk($updateData[$flag.'_true'], 1000) as $chunk) {
+				foreach (array_chunk($updateData[$flag . '_true'], 1000) as $chunk) {
 					$queryTrue->setParameter('uids', $chunk, IQueryBuilder::PARAM_INT_ARRAY);
 					$queryTrue->executeStatement();
 				}
@@ -474,7 +491,7 @@ class MessageMapper extends QBMapper {
 						$queryFalse->expr()->eq('mailbox_id', $queryFalse->createNamedParameter($mailboxId, IQueryBuilder::PARAM_INT)),
 						$queryFalse->expr()->eq($flag, $queryFalse->createNamedParameter(1, IQueryBuilder::PARAM_INT))
 					));
-				foreach (array_chunk($updateData[$flag.'_false'], 1000) as $chunk) {
+				foreach (array_chunk($updateData[$flag . '_false'], 1000) as $chunk) {
 					$queryFalse->setParameter('uids', $chunk, IQueryBuilder::PARAM_INT_ARRAY);
 					$queryFalse->executeStatement();
 				}
@@ -563,6 +580,7 @@ class MessageMapper extends QBMapper {
 				->set('updated_at', $query->createNamedParameter($this->timeFactory->getTime(), IQueryBuilder::PARAM_INT))
 				->set('imip_message', $query->createParameter('imip_message'))
 				->set('encrypted', $query->createParameter('encrypted'))
+				->set('mentions_me', $query->createParameter('mentions_me'))
 				->where($query->expr()->andX(
 					$query->expr()->eq('uid', $query->createParameter('uid')),
 					$query->expr()->eq('mailbox_id', $query->createParameter('mailbox_id'))
@@ -593,6 +611,7 @@ class MessageMapper extends QBMapper {
 				);
 				$query->setParameter('imip_message', $message->isImipMessage(), IQueryBuilder::PARAM_BOOL);
 				$query->setParameter('encrypted', $message->isEncrypted(), IQueryBuilder::PARAM_BOOL);
+				$query->setParameter('mentions_me', $message->getMentionsMe(), IQueryBuilder::PARAM_BOOL);
 
 				$query->executeStatement();
 			}
@@ -930,7 +949,7 @@ class MessageMapper extends QBMapper {
 		if ($uids !== null) {
 			// In the case of body+subject search we need a combination of both results,
 			// thus the orWhere in every other case andWhere should do the job.
-			if(!empty($query->getSubjects())) {
+			if (!empty($query->getSubjects())) {
 				$textOrs[] = $qb->expr()->in('m.uid', $qb->createParameter('uids'));
 			} else {
 				$select->andWhere(
@@ -961,6 +980,12 @@ class MessageMapper extends QBMapper {
 			);
 		}
 
+		if ($query->getMentionsMe()) {
+			$select->andWhere(
+				$qb->expr()->eq('m.mentions_me', $qb->createNamedParameter($query->getMentionsMe(), IQueryBuilder::PARAM_BOOL))
+			);
+		}
+
 		if ($query->getCursor() !== null && $sortOrder === IMailSearch::ORDER_NEWEST_FIRST) {
 			$select->andWhere(
 				$qb->expr()->lt('m.sent_at', $qb->createNamedParameter($query->getCursor(), IQueryBuilder::PARAM_INT))
